@@ -11,6 +11,7 @@ class ShortKeyError(KeyError):
 
 
 TrieKey = Union[Tuple[()], Tuple[str]]
+TrieStep = Tuple[Optional[TrieKey], Optional[bytes]]
 
 
 class TrieNode(NamedTuple):
@@ -85,20 +86,22 @@ class AbstractTrie(MutableMapping):
         pass
 
     @abstractmethod
-    def shortest_prefix(
-        self, key: TrieKey
-    ) -> Tuple[Optional[TrieKey], Optional[bytes]]:
+    def prefixes(self, key: TrieKey) -> Iterator[TrieStep]:
         pass
 
     @abstractmethod
-    def longest_prefix(
-        self, key: TrieKey
-    ) -> Tuple[Optional[TrieKey], Optional[bytes]]:
+    def shortest_prefix(self, key: TrieKey) -> Optional[TrieStep]:
+        pass
+
+    @abstractmethod
+    def longest_prefix(self, key: TrieKey) -> Optional[TrieStep]:
         pass
 
     @abstractmethod
     # pylint: disable-next=invalid-name
-    def ls(self, key: TrieKey) -> Iterator[TrieKey]:
+    def ls(
+        self, key: TrieKey, with_values: bool = False
+    ) -> Iterator[Union[TrieKey, TrieNode]]:
         pass
 
     @abstractmethod
